==> portmanager-0.2.9.tar.gz: portmanager-0.2.9/libMG/src/MGdbSeek.c <==
/************************************************************************/
/*	Copyright (C) 2005  Michael C. Shultz				*/
/*									*/
/* This program is free software; you can redistribute it and/or modify */
/* it under the terms of the GNU General Public License as published by */
/* the Free Software Foundation; either version 2 of the License, or (at*/
/* your option) any later version.					*/
/*									*/
/* This program is distributed in the hope that it will be useful,	*/
/* but WITHOUT ANY WARRANTY; without even the implied warranty of	*/
/* MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the	*/
/* GNU General Public License for more details. 			*/
/*									*/
/* You should have received a copy of the GNU General Public License	*/
/* along with this program; if not, write to the Free Software		*/
/* Foundation, Inc., 59 Temple Place - Suite 330, Boston, MA		*/
/*  02111-1307, USA.							*/
/* 									*/
/* Michael C. Shultz							*/
/* ringworm01@gmail.com							*/
/* Box 3238 Landers, CA 92285						*/
/************************************************************************/
#include	<libMG.h>
#include	<libMG.ph>

char* MGdbSeek( classDb* db, char* fieldName, char* keyValue, char* returnField )
{
	char	id[]	= "MGdbSeek";
	
	/***************************************************************/
	/* check if we have a valid object                             */
	/***************************************************************/
	if(db == NULL || db->parent.type != CLASS_TYPE_DB  )
	{
		fprintf( stderr, "%s error: invalid object type\n", id);
		assert(0);
	}

	if( db->parent.recordIdx >= db->parent.recordQty )
	{
		return(NULL);
	} 

	if( !fieldName )
	{
		fprintf( stderr, "%s error: parameter 2 (char* fieldName) is NULL!\n", id );
		assert(0);
	}

	if( !keyValue )
	{
		fprintf( stderr, "%s error: parameter 3 (char* keyValue) is NULL!\n", id );
		assert(0);
	}

	if( !returnField )
	{
		fprintf( stderr, "%s error: parameter 4 (char* returnField) is NULL!\n", id );
		assert(0);
	}

	if( !db->record[0][0] )
	{
		fprintf( stderr, "%s error: record 0 field 0 contains nothing!\n",
			id );
		fprintf( stderr, "fieldName = %s\ndb->parent.recordQty = %d\ndb->fieldQty = %d\n",
			fieldName, db->parent.recordQty, db->fieldQty );
		assert(0);
	}

	db->fieldIdx	= 0;
	while( strcmp( fieldName, db->record[0][db->fieldIdx] ) )
	{
		db->fieldIdx++;
		if( db->fieldIdx >= db->fieldQty )
		{
			fprintf( stderr, "%s error: field \"%s\" not found in %s\n",
				id, fieldName, db->parent.path );
			assert(0);
		}
	}	

	/* find matching keyValue */
	while( strncmp( db->record[db->parent.recordIdx][db->fieldIdx], keyValue, strlen(keyValue) ) )
	{
		db->parent.recordIdx++;
		if( db->parent.recordIdx  == db->parent.recordQty )
		{
			return(NULL);
		}		 
	}

	db->fieldIdx	= 0;
	while( strcmp( returnField, db->record[0][db->fieldIdx] ) )
	{
		db->fieldIdx++;
		if(db->fieldIdx == db->fieldQty)
		{
			fprintf( stderr, "%s error: field \"%s\" not found in %s\n",
				id, returnField, db->parent.path );
			fflush(stderr);
			assert(0);
		}
	}	

	db->parent.recordIdx++;
	return( db->record[db->parent.recordIdx-1][db->fieldIdx] );
}

==> portmanager-0.3.4.tar.gz: portmanager-0.3.4/libMG/src/MGdbSeek.c <==
/************************************************************************/
/*	Copyright (C) 2005  Michael C. Shultz				*/
/*									*/
/* This program is free software; you can redistribute it and/or modify */
/* it under the terms of the GNU General Public License as published by */
/* the Free Software Foundation; either version 2 of the License, or (at*/
/* your option) any later version.					*/
/*									*/
/* This program is distributed in the hope that it will be useful,	*/
/* but WITHOUT ANY WARRANTY; without even the implied warranty of	*/
/* MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the	*/
/* GNU General Public License for more details. 			*/
/*									*/
/* You should have received a copy of the GNU General Public License	*/
/* along with this program; if not, write to the Free Software		*/
/* Foundation, Inc., 59 Temple Place - Suite 330, Boston, MA		*/
/*  02111-1307, USA.							*/
/* 									*/
/* Michael C. Shultz							*/
/* ringworm01@gmail.com							*/
/* Box 3238 Landers, CA 92285						*/
/************************************************************************/
#include	<libMG.h>
#include	<libMG.ph>

char* MGdbSeek( classDb* db, char* fieldName, char* keyValue, char* returnField, char* exact )
{
	char	id[]	= "MGdbSeek";
	
	/***************************************************************/
	/* check if we have a valid object                             */
	/***************************************************************/
	if(db == NULL || db->parent.type != CLASS_TYPE_DB  )
	{
		fprintf( stderr, "%s error: invalid object type\n", id);
		assert(0);
	}

	if( db->parent.recordIdx >= db->parent.recordQty )
	{
		return(NULL);
	} 

	if( !fieldName )
	{
		fprintf( stderr, "%s error: parameter 2 (char* fieldName) is NULL!\n", id );
		assert(0);
	}

	if( !keyValue )
	{
		fprintf( stderr, "%s error: parameter 3 (char* keyValue) is NULL!\n", id );
		assert(0);
	}

	if( !returnField )
	{
		fprintf( stderr, "%s error: parameter 4 (char* returnField) is NULL!\n", id );
		assert(0);
	}

	if( !exact )
	{
		fprintf( stderr, "%s error: parameter 5 (char* exact) is NULL! Must be either \"exact\" or \"anything else\" \n", id );
		assert(0);
	}

	if( !db->record[0][0] )
	{
		fprintf( stderr, "%s error: record 0 field 0 contains nothing!\n",
			id );
		fprintf( stderr, "fieldName = %s\ndb->parent.recordQty = %d\ndb->fieldQty = %d\n",
			fieldName, db->parent.recordQty, db->fieldQty );
		assert(0);
	}

	db->fieldIdx	= 0;
	while( strcmp( fieldName, db->record[0][db->fieldIdx] ) )
	{
		db->fieldIdx++;
		if( db->fieldIdx >= db->fieldQty )
		{
			fprintf( stderr, "%s error: field \"%s\" not found in %s\n",
				id, fieldName, db->parent.path );
			assert(0);
		}
	}	

	if( strcmp( exact, "exact" ) == 0 )
	{
		while( strncmp( db->record[db->parent.recordIdx][db->fieldIdx], keyValue, strlen(keyValue) ) ||
			strlen( db->record[db->parent.recordIdx][db->fieldIdx] ) != strlen( keyValue ) )
		{
			db->parent.recordIdx++;
			if( db->parent.recordIdx  == db->parent.recordQty )
			{
				return(NULL);
			}		 
		}
	}
	else
	{
		while( strncmp( db->record[db->parent.recordIdx][db->fieldIdx], keyValue, strlen(keyValue) ) )
		{
			db->parent.recordIdx++;
			if( db->parent.recordIdx  == db->parent.recordQty )
			{
				return(NULL);
			}		 
		}
	}
	
	db->fieldIdx	= 0;
	while( strcmp( returnField, db->record[0][db->fieldIdx] ) )
	{
		db->fieldIdx++;
		if(db->fieldIdx == db->fieldQty)
		{
			fprintf( stderr, "%s error: field \"%s\" not found in %s\n",
				id, returnField, db->parent.path );
			fflush(stderr);
			assert(0);
		}
	}	

	db->parent.recordIdx++;
	return( db->record[db->parent.recordIdx-1][db->fieldIdx] );
}
